@@ -1,12 +1,13 @@
-import requests
 import re
 import struct
+from functools import reduce
+
+import requests
 
 from django.http import HttpResponse
 from django.views.decorators.cache import never_cache
 from google_analytics.utils import build_ga_params, set_cookie
 
-
 GIF_DATA = reduce(lambda x, y: x + struct.pack('B', y),
                   [0x47, 0x49, 0x46, 0x38, 0x39, 0x61,
                    0x01, 0x00, 0x01, 0x00, 0x80, 0x00,
@@ -14,13 +15,13 @@ GIF_DATA = reduce(lambda x, y: x + struct.pack('B', y),
                    0xff, 0x21, 0xf9, 0x04, 0x01, 0x00,
                    0x00, 0x00, 0x00, 0x2c, 0x00, 0x00,
                    0x00, 0x00, 0x01, 0x00, 0x01, 0x00,
-                   0x00, 0x02, 0x01, 0x44, 0x00, 0x3b], '')
+                   0x00, 0x02, 0x01, 0x44, 0x00, 0x3b], b'')
 
 
 def get_ip(remote_address):
     if not remote_address:
         return ''
-    matches = re.match('^([^.]+\.[^.]+\.[^.]+\.).*', remote_address)
+    matches = re.match(r'^([^.]+\.[^.]+\.[^.]+\.).*', remote_address)
     if matches:
         return matches.groups()[0] + "0"
     else:
